"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore


class QDBusArgument(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdbusargument.html

    **Detailed Description**

    The class is used to send arguments over D-Bus to remote applications and to
    receive them back. D-Bus offers an extensible type system, based on a few
    primitive types and associations of them. See the **Qt D-Bus Type System**
    page for more information on the type system.

    QDBusArgument is the central class in the Qt D-Bus type system, providing
    functions to marshall and demarshall the primitive types. The compound types
    are then created by association of one or more of the primitive types in
    arrays, dictionaries or structures.

    The following example illustrates how a structure containing an integer and
    a string can be constructed using the **Qt D-Bus type system** :

    struct MyStructure
        {
            int count;
            **QString**  name;
    // ...
        };
        Q_DECLARE_METATYPE(MyStructure)

        // Marshall the
    MyStructure data into a D-Bus argument
        **QDBusArgument**
    &operator<<(**QDBusArgument**  &argument, const MyStructure &myStruct)
        {
    argument.beginStructure();
            argument << myStruct.count <<
    myStruct.name;
            argument.endStructure();
            return argument;
    }

        // Retrieve the MyStructure data from the D-Bus argument
    const **QDBusArgument**  &operator>>(const **QDBusArgument**  &argument,
    MyStructure &myStruct)
        {
            argument.beginStructure();
    argument >> myStruct.count >> myStruct.name;
    argument.endStructure();
            return argument;
        }

    The type has to be registered with **qDBusRegisterMetaType** () before it
    can be used with QDBusArgument. Therefore, somewhere in your program, you
    should add the following code:

    qDBusRegisterMetaType<MyStructure>();

    Once registered, a type can be used in outgoing method calls (placed with
    **QDBusAbstractInterface::call** ()), signal emissions from registered
    objects or in incoming calls from remote applications.

    It is important to note that the `operator<<` and `operator>>` streaming
    functions must always produce the same number of entries in case of
    structures, both in reading and in writing (marshalling and demarshalling),
    otherwise calls and signals may start to silently fail.

    The following example illustrates this wrong usage in context of a class
    that may contain invalid data:

    //bad code
            // Wrongly marshall the MyTime data into a D-Bus argument
    **QDBusArgument**  &operator<<(**QDBusArgument**  &argument, const MyTime
    &mytime)
            {
                argument.beginStructure();
                if
    (mytime.isValid)
                    argument << true << mytime.hour
    << mytime.minute << mytime.second;
                else
                    argument
    << false;
                argument.endStructure();
                return argument;
    }

    In this example, both the `operator<<` and the `operator>>` functions may
    produce a different number of reads/writes. This can confuse the Qt D-Bus
    type system and should be avoided.

    **See also** **QDBusAbstractInterface** , **The Qt D-Bus type system** ,
    **Using Adaptors** , and **qdbus_cast** ().
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdbusargument.html#QDBusArgument

        **QDBusArgument::QDBusArgument()**

        Constructs an empty QDBusArgument argument.

        An empty QDBusArgument object does not allow either reading or writing
        to be performed.
        """
        ...

    @typing.overload
    def __init__(self, other: "QDBusArgument") -> None:
        """
        https://doc.qt.io/qt-6/qdbusargument.html#QDBusArgument-1

        **QDBusArgument::QDBusArgument(const QDBusArgument & other )**

        Constructs a copy of the **other** QDBusArgument object.

        Both objects will therefore contain the same state from this point
        forward. QDBusArguments are explicitly shared and, therefore, any
        modification to either copy will affect the other one too.
        """
        ...

    @typing.overload
    def __init__(self, arg: typing.Any, id: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qdbusargument.html#QDBusArgument

        **QDBusArgument::QDBusArgument()**

        Constructs an empty QDBusArgument argument.

        An empty QDBusArgument object does not allow either reading or writing
        to be performed.
        """
        ...

    def swap(self, other: "QDBusArgument") -> None:
        """
        https://doc.qt.io/qt-6/qdbusargument.html#swap

        **void QDBusArgument::swap(QDBusArgument & other )**

        Swaps this **QDBusArgument**  instance with **other**.
        """
        ...

    def endMapEntry(self) -> None:
        """
        https://doc.qt.io/qt-6/qdbusargument.html#endMapEntry

        **void QDBusArgument::endMapEntry()**

        Closes a D-Bus map entry opened with **beginMapEntry** (). This function
        must be called same number of times that **beginMapEntry** () is called.

        **See also** **beginMapEntry** ().
        """
        ...

    def beginMapEntry(self) -> None:
        """
        https://doc.qt.io/qt-6/qdbusargument.html#beginMapEntry

        **void QDBusArgument::beginMapEntry()**

        Opens a D-Bus map entry suitable for appending the key and value
        entries. This function is only valid when a map has been opened with
        **beginMap** ().

        See **beginMap** () for an example of usage of this function.

        **See also** **endMapEntry** () and **beginMap** ().
        """
        ...

    def endMap(self) -> None:
        """
        https://doc.qt.io/qt-6/qdbusargument.html#endMap

        **void QDBusArgument::endMap()**

        Closes a D-Bus map opened with **beginMap** (). This function must be
        called same number of times that **beginMap** () is called.

        **See also** **beginMap** (), **endStructure** (), and **endArray** ().
        """
        ...

    @typing.overload
    def beginMap(
        self, keyMetaType: QtCore.QMetaType, valueMetaType: QtCore.QMetaType
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdbusargument.html#beginMap-1

        **void QDBusArgument::beginMap(QMetaType keyMetaType , QMetaType
        valueMetaType )**

        Opens a new D-Bus map suitable for appending elements. Maps are
        containers that associate one entry (the key) to another (the value),
        such as Qt's **QMap**  or **QHash** . The ids of the map's key and value
        meta types must be passed in **keyMetaType** and **valueMetaType**
        respectively.

        This function is used usually in `operator<<` streaming operators, as in
        the following example:

        // Append a dictionary that associates ints to MyValue types
        **QDBusArgument**  &operator<<(**QDBusArgument**  &argument, const
        MyDictionary &myDict)
            {
                argument.beginMap(**QMetaType**
        ::fromType<int>(), **QMetaType** ::fromType<MyValue>());
        MyDictionary::const_iterator i;
                for (i = myDict.cbegin(); i !=
        myDict.cend(); ++i) {
                    argument.beginMapEntry();
        argument << i.key() << i.value();
                    argument.endMapEntry();
        }
                argument.endMap();
                return argument;
            }

        You usually don't need to provide an `operator<<` or `operator>>`
        function for associative containers such as **QHash**  or std::map,
        since Qt D-Bus provides generic templates to do the job of marshalling
        the data.

        **See also** **endMap** (), **beginStructure** (), **beginArray** (),
        and **beginMapEntry** ().
        """
        ...

    @typing.overload
    def beginMap(self, kid: int, vid: int) -> None:
        """
        https://doc.qt.io/qt-6/qdbusargument.html#beginMap-2

        **void QDBusArgument::beginMap() const**

        Recurses into the D-Bus map to allow extraction of the map's elements.

        This function is used usually in `operator>>` streaming operators, as in
        the following example:

        // Extract a MyDictionary map that associates integers to MyElement
        items
            const **QDBusArgument**  &operator>>(const **QDBusArgument**
        &argument, MyDictionary &myDict)
            {
                argument.beginMap();
        myDict.clear();

                while (!argument.atEnd()) {
                    int
        key;
                    MyElement value;
                    argument.beginMapEntry();
        argument >> key >> value;
                    argument.endMapEntry();
        myDict.insert(key, value);
                }

                argument.endMap();
        return argument;
            }

        If the type you want to demarshall is a **QMap**  or **QHash** , you
        need not declare an `operator>>` function for it, since Qt D-Bus
        provides generic templates to do the job of demarshalling the data.

        **See also** **endMap** (), **beginStructure** (), **beginArray** (),
        and **beginMapEntry** ().
        """
        ...

    def endArray(self) -> None:
        """
        https://doc.qt.io/qt-6/qdbusargument.html#endArray

        **void QDBusArgument::endArray()**

        Closes a D-Bus array opened with **beginArray** (). This function must
        be called same number of times that **beginArray** () is called.

        **See also** **beginArray** (), **endStructure** (), and **endMap** ().
        """
        ...

    @typing.overload
    def beginArray(self, elementMetaType: QtCore.QMetaType) -> None:
        """
        https://doc.qt.io/qt-6/qdbusargument.html#beginArray-1

        **void QDBusArgument::beginArray(QMetaType id )**

        Opens a new D-Bus array suitable for appending elements of meta-type
        **id**.

        This function is used usually in `operator<<` streaming operators, as in
        the following example:

        // Append an array of MyElement types
            **QDBusArgument**
        &operator<<(**QDBusArgument**  &argument, const MyArray &myArray)
            {
        argument.beginArray(**qMetaTypeId** <MyElement>());
                for (const
        auto &element : myArray)
                    argument << element;
        argument.endArray();
                return argument;
            }

        If the type you want to marshall is a **QList**  or any of the Qt's
        **Container Classes**  that take one template parameter, you need not
        declare an `operator<<` function for it, since Qt D-Bus provides generic
        templates to do the job of marshalling the data. The same applies for
        STL's sequence containers, such as `std::list`, `std::vector`, etc.

        **See also** **endArray** (), **beginStructure** (), and **beginMap**
        ().
        """
        ...

    @typing.overload
    def beginArray(self, id: int) -> None:
        """
        https://doc.qt.io/qt-6/qdbusargument.html#beginArray-2

        **void QDBusArgument::beginArray() const**

        Recurses into the D-Bus array to allow extraction of the array elements.

        This function is used usually in `operator>>` streaming operators, as in
        the following example:

        // Extract a MyArray array of MyElement elements
            const
        **QDBusArgument**  &operator>>(const **QDBusArgument**  &argument,
        MyArray &myArray)
            {
                argument.beginArray();
        myArray.clear();

                while (!argument.atEnd()) {
        MyElement element;
                    argument >> element;
        myArray.append(element);
                }

                argument.endArray();
        return argument;
            }

        If the type you want to demarshall is a **QList**  or any of the Qt's
        **Container Classes**  that take one template parameter, you need not
        declare an `operator>>` function for it, since Qt D-Bus provides generic
        templates to do the job of demarshalling the data. The same applies for
        STL's sequence containers, such as `std::list`, `std::vector`, etc.

        **See also** **atEnd** (), **beginStructure** (), and **beginMap** ().
        """
        ...

    def endStructure(self) -> None:
        """
        https://doc.qt.io/qt-6/qdbusargument.html#endStructure

        **void QDBusArgument::endStructure()**

        Closes a D-Bus structure opened with **beginStructure** (). This
        function must be called same number of times that **beginStructure** ()
        is called.

        **See also** **beginStructure** (), **endArray** (), and **endMap** ().
        """
        ...

    def beginStructure(self) -> None:
        """
        https://doc.qt.io/qt-6/qdbusargument.html#beginStructure

        **void QDBusArgument::beginStructure()**

        Opens a new D-Bus structure suitable for appending new arguments.

        This function is used usually in `operator<<` streaming operators, as in
        the following example:

        **QDBusArgument**  &operator<<(**QDBusArgument**  &argument, const
        MyStructure &myStruct)
            {
                argument.beginStructure();
        argument << myStruct.member1 << myStruct.member2;
        argument.endStructure();
                return argument;
            }

        Structures can contain other structures, so the following code is also
        valid:

        **QDBusArgument**  &operator<<(**QDBusArgument**  &argument, const
        MyStructure &myStruct)
            {
                argument.beginStructure();
        argument << myStruct.member1 << myStruct.member2;
        argument.beginStructure();
                argument <<
        myStruct.member3.subMember1 << myStruct.member3.subMember2;
        argument.endStructure();

                argument << myStruct.member4;
        argument.endStructure();
                return argument;
            }

        **See also** **endStructure** (), **beginArray** (), and **beginMap**
        ().
        """
        ...

    def add(self, arg: typing.Any, id: int = ...) -> None:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtMultimedia import *


class QAudioSink(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qaudiosink.html

    **Detailed Description**

    You can construct an audio output with the system's default audio output
    device. It is also possible to create QAudioSink with a specific
    **QAudioDevice** . When you create the audio output, you should also send in
    the **QAudioFormat**  to be used for the playback (see the **QAudioFormat**
    class description for details).

    To play a file:

    Starting to play an audio stream is simply a matter of calling **start** ()
    with a **QIODevice** . QAudioSink will then fetch the data it needs from the
    io device. So playing back an audio file is as simple as:

    **QFile**  sourceFile;   // class member.
        **QAudioSink** * audio; //
    class member.
        {
            sourceFile.setFileName("/tmp/test.raw");
    sourceFile.open(**QIODevice** ::ReadOnly);

            **QAudioFormat**
    format;
            // Set up the format, eg.
    format.setSampleRate(8000);
            format.setChannelCount(1);
    format.setSampleFormat(**QAudioFormat** ::UInt8);
    **QAudioDevice**  info(**QAudioDevice** ::defaultOutputDevice());
            if
    (!info.isFormatSupported(format)) {
                **qWarning** () << "Raw
    audio format not supported by backend, cannot play audio.";
    return;
            }

            audio = new **QAudioSink** (format, this);
    connect(audio, SIGNAL(stateChanged(QAudio::State)), this,
    SLOT(handleStateChanged(QAudio::State)));
            audio->start(&sourceFile);
    }

    The file will start playing assuming that the audio system and output device
    support it. If you run out of luck, check what's up with the **error** ()
    function.

    After the file has finished playing, we need to stop the device:

    void AudioOutputExample::handleStateChanged(QAudio::State newState)
        {
    switch (newState) {
                case QAudio::IdleState:
                    //
    Finished playing (no more data)
                    audio->stop();
    sourceFile.close();
                    delete audio;
                    break;
    case QAudio::StoppedState:
                    // Stopped for other reasons
    if (audio->error() != QAudio::NoError) {
                        // Error
    handling
                    }
                    break;

                default:
    // ... other cases as appropriate
                    break;
            }
        }

    At any given time, the QAudioSink will be in one of four states: active,
    suspended, stopped, or idle. These states are described by the
    **QAudio::State**  enum. State changes are reported through the
    **stateChanged** () signal. You can use this signal to, for instance, update
    the GUI of the application; the mundane example here being changing the
    state of a `play/pause` button. You request a state change directly with
    **suspend** (), **stop** (), **reset** (), **resume** (), and **start** ().

    If an error occurs, you can fetch the **error type**  with the **error** ()
    function. Please see the **QAudio::Error**  enum for a description of the
    possible errors that are reported. When an error is encountered, the state
    changes to **QAudio::StoppedState** . You can check for errors by connecting
    to the **stateChanged** () signal:

    void AudioOutputExample::handleStateChanged(QAudio::State newState)
        {
    switch (newState) {
                case QAudio::IdleState:
                    //
    Finished playing (no more data)
                    audio->stop();
    sourceFile.close();
                    delete audio;
                    break;
    case QAudio::StoppedState:
                    // Stopped for other reasons
    if (audio->error() != QAudio::NoError) {
                        // Error
    handling
                    }
                    break;

                default:
    // ... other cases as appropriate
                    break;
            }
        }

    **See also** **QAudioSource**  and **QAudioDevice** .
    """

    @typing.overload
    def __init__(
        self,
        audioDeviceInfo: QAudioDevice,
        format: QAudioFormat = ...,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qaudiosink.html#QAudioSink

        **QAudioSink::QAudioSink(const QAudioFormat & format = QAudioFormat(),
        QObject * parent = nullptr)**

        Construct a new audio output and attach it to **parent**. The default
        audio output device is used with the output **format** parameters.
        """
        ...

    @typing.overload
    def __init__(
        self, format: QAudioFormat = ..., parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qaudiosink.html#QAudioSink-1

        **QAudioSink::QAudioSink(const QAudioDevice & audioDevice , const
        QAudioFormat & format = QAudioFormat(), QObject * parent = nullptr)**

        Construct a new audio output and attach it to **parent**. The device
        referenced by **audioDevice** is used with the output **format**
        parameters.
        """
        ...

    def volume(self) -> float:
        """
        https://doc.qt.io/qt-6/qaudiosink.html#volume

        **qreal QAudioSink::volume() const**

        Returns the volume between 0.0 and 1.0 inclusive.

        **See also** **setVolume** ().
        """
        ...

    def setVolume(self, a0: float) -> None:
        """
        https://doc.qt.io/qt-6/qaudiosink.html#setVolume

        **void QAudioSink::setVolume(qreal volume )**

        Sets the output volume to **volume**.

        The volume is scaled linearly from `0.0` (silence) to `1.0` (full
        volume). Values outside this range will be clamped.

        The default volume is `1.0`.

        **Note:** Adjustments to the volume will change the volume of this audio
        stream, not the global volume.

        UI volume controls should usually be scaled non-linearly. For example,
        using a logarithmic scale will produce linear changes in perceived
        loudness, which is what a user would normally expect from a volume
        control. See **QAudio::convertVolume** () for more details.

        **See also** **volume** ().
        """
        ...

    def state(self) -> QAudio.State:
        """
        https://doc.qt.io/qt-6/qaudiosink.html#state

        **QAudio::State QAudioSink::state() const**

        Returns the state of audio processing.
        """
        ...

    def error(self) -> QAudio.Error:
        """
        https://doc.qt.io/qt-6/qaudiosink.html#error

        **QAudio::Error QAudioSink::error() const**

        Returns the error state.
        """
        ...

    def elapsedUSecs(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudiosink.html#elapsedUSecs

        **qint64 QAudioSink::elapsedUSecs() const**

        Returns the microseconds since **start** () was called, including time
        in Idle and Suspend states.
        """
        ...

    def processedUSecs(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudiosink.html#processedUSecs

        **qint64 QAudioSink::processedUSecs() const**

        Returns the amount of audio data processed since **start** () was called
        (in microseconds).
        """
        ...

    def bytesFree(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudiosink.html#bytesFree

        **qsizetype QAudioSink::bytesFree() const**

        Returns the number of free bytes available in the audio buffer.

        **Note:** The returned value is only valid while in
        **QAudio::ActiveState**  or **QAudio::IdleState**  state, otherwise
        returns zero.
        """
        ...

    def bufferSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudiosink.html#bufferSize

        **qsizetype QAudioSink::bufferSize() const**

        Returns the audio buffer size in bytes.

        If called before **start** (), returns platform default value. If called
        before **start** () but **setBufferSize** () was called prior, returns
        value set by **setBufferSize** (). If called after **start** (), returns
        the actual buffer size being used. This may not be what was set
        previously by **setBufferSize** ().

        **See also** **setBufferSize** ().
        """
        ...

    def setBufferSize(self, bytes: int) -> None:
        """
        https://doc.qt.io/qt-6/qaudiosink.html#setBufferSize

        **void QAudioSink::setBufferSize(qsizetype value )**

        Sets the audio buffer size to **value** in bytes.

        **Note:** This function can be called anytime before **start** (). Calls
        to this are ignored after **start** (). It should not be assumed that
        the buffer size set is the actual buffer size used - call **bufferSize**
        () anytime after **start** () to return the actual buffer size being
        used.

        **See also** **bufferSize** ().
        """
        ...

    def resume(self) -> None:
        """
        https://doc.qt.io/qt-6/qaudiosink.html#resume

        **void QAudioSink::resume()**

        Resumes processing audio data after a **suspend** ().

        Sets **error** () to **QAudio::NoError** . Sets **state** () to
        **QAudio::ActiveState**  if you previously called start(**QIODevice**
        *). Sets **state** () to **QAudio::IdleState**  if you previously called
        **start** (). emits **stateChanged** () signal.
        """
        ...

    def suspend(self) -> None:
        """
        https://doc.qt.io/qt-6/qaudiosink.html#suspend

        **void QAudioSink::suspend()**

        Stops processing audio data, preserving buffered audio data.

        Sets **error** () to **QAudio::NoError** , **state** () to
        **QAudio::SuspendedState**  and emits **stateChanged** () signal.
        """
        ...

    def reset(self) -> None:
        """
        https://doc.qt.io/qt-6/qaudiosink.html#reset

        **void QAudioSink::reset()**

        Drops all audio data in the buffers, resets buffers to zero.
        """
        ...

    def stop(self) -> None:
        """
        https://doc.qt.io/qt-6/qaudiosink.html#stop

        **void QAudioSink::stop()**

        Stops the audio output, detaching from the system resource.

        Sets **error** () to **QAudio::NoError** , **state** () to
        **QAudio::StoppedState**  and emit **stateChanged** () signal.
        """
        ...

    @typing.overload
    def start(self, device: QtCore.QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qaudiosink.html#start

        **void QAudioSink::start(QIODevice * device )**

        Starts transferring audio data from the **device** to the system's audio
        output. The **device** must have been opened in the **ReadOnly**  or
        **ReadWrite**  modes.

        If the **QAudioSink**  is able to successfully output audio data,
        **state** () returns **QAudio::ActiveState** , **error** () returns
        **QAudio::NoError**  and the **stateChanged** () signal is emitted.

        If a problem occurs during this process, **error** () returns
        **QAudio::OpenError** , **state** () returns **QAudio::StoppedState**
        and the **stateChanged** () signal is emitted.

        **See also** **QIODevice** .
        """
        ...

    @typing.overload
    def start(self) -> QtCore.QIODevice:
        """
        https://doc.qt.io/qt-6/qaudiosink.html#start-1

        **QIODevice *QAudioSink::start()**

        Returns a pointer to the internal **QIODevice**  being used to transfer
        data to the system's audio output. The device will already be open and
        **write** () can write data directly to it.

        **Note:** The pointer will become invalid after the stream is stopped or
        if you start another stream.

        If the **QAudioSink**  is able to access the system's audio device,
        **state** () returns **QAudio::IdleState** , **error** () returns
        **QAudio::NoError**  and the **stateChanged** () signal is emitted.

        If a problem occurs during this process, **error** () returns
        **QAudio::OpenError** , **state** () returns **QAudio::StoppedState**
        and the **stateChanged** () signal is emitted.

        **See also** **QIODevice** .
        """
        ...

    def format(self) -> QAudioFormat:
        """
        https://doc.qt.io/qt-6/qaudiosink.html#format

        **QAudioFormat QAudioSink::format() const**

        Returns the **QAudioFormat**  being used.
        """
        ...

    @property
    def stateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qaudiosink.html#stateChanged

        **[signal] void QAudioSink::stateChanged(QAudio::State state )**

        This signal is emitted when the device **state** has changed. This is
        the current state of the audio output.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui


class QDesignerTaskMenuExtension(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdesignertaskmenuextension.html

    **Detailed Description**

    QDesignerTaskMenuExtension provides an interface for creating custom task
    menu extensions. It is typically used to create task menu entries that are
    specific to a plugin in **Qt Designer**.

    **Qt Designer** uses the QDesignerTaskMenuExtension to feed its task menu.
    Whenever a task menu is requested, **Qt Designer** will query for the
    selected widget's task menu extension.

    ![](images/taskmenuextension-example-faded.png)

    A task menu extension is a collection of QActions. The actions appear as
    entries in the task menu when the plugin with the specified extension is
    selected. The image above shows the custom **Edit State...** action which
    appears in addition to **Qt Designer** 's default task menu entries: **Cut**
    , **Copy** , **Paste** etc.

    To create a custom task menu extension, your extension class must inherit
    from both **QObject**  and QDesignerTaskMenuExtension. For example:

    class MyTaskMenuExtension : public **QObject** ,
                public
    QDesignerTaskMenuExtension
        {
            Q_OBJECT
    Q_INTERFACES(QDesignerTaskMenuExtension)

        public:
    MyTaskMenuExtension(MyCustomWidget *widget, **QObject**  *parent);
    **QAction**  *preferredEditAction() const;
            **QList** <**QAction**
    *> taskActions() const;

        private slots:
            void mySlot();
    private:
            MyCustomWidget *widget;
            **QAction**  *myAction;
    };

    Since we are implementing an interface, we must ensure that it is made known
    to the meta-object system using the **Q_INTERFACES** () macro. This enables
    **Qt Designer** to use the **qobject_cast** () function to query for
    supported interfaces using nothing but a **QObject**  pointer.

    You must reimplement the **taskActions** () function to return a list of
    actions that will be included in **Qt Designer** task menu. Optionally, you
    can reimplement the **preferredEditAction** () function to set the action
    that is invoked when selecting your plugin and pressing **F2**. The
    preferred edit action must be one of the actions returned by **taskActions**
    () and, if it's not defined, pressing the **F2** key will simply be ignored.

    In **Qt Designer** , extensions are not created until they are required. A
    task menu extension, for example, is created when you click the right mouse
    button over a widget in **Qt Designer** 's workspace. For that reason you
    must also construct an extension factory, using either **QExtensionFactory**
    or a subclass, and register it using **Qt Designer** 's **extension
    manager** .

    When a task menu extension is required, **Qt Designer** 's **extension
    manager**  will run through all its registered factories calling
    **QExtensionFactory::createExtension** () for each until it finds one that
    is able to create a task menu extension for the selected widget. This
    factory will then make an instance of the extension.

    There are four available types of extensions in **Qt Designer** :
    **QDesignerContainerExtension** , **QDesignerMemberSheetExtension** ,
    **QDesignerPropertySheetExtension** , and QDesignerTaskMenuExtension. **Qt
    Designer** 's behavior is the same whether the requested extension is
    associated with a container, a member sheet, a property sheet or a task
    menu.

    The **QExtensionFactory**  class provides a standard extension factory, and
    can also be used as an interface for custom extension factories. You can
    either create a new **QExtensionFactory**  and reimplement the
    **QExtensionFactory::createExtension** () function. For example:

    **QObject**  *ANewExtensionFactory::createExtension(**QObject**  *object,
    const **QString**  &iid, **QObject**  *parent) const
        {
            if (iid
    != Q_TYPEID(QDesignerTaskMenuExtension))
                return 0;
    if (MyCustomWidget *widget = qobject_cast<MyCustomWidget*>(object))
    return new MyTaskMenuExtension(widget, parent);

            return 0;
        }

    Or you can use an existing factory, expanding the
    **QExtensionFactory::createExtension** () function to make the factory able
    to create a task menu extension as well. For example:

    **QObject**  *AGeneralExtensionFactory::createExtension(**QObject**
    *object,
                const **QString**  &iid, **QObject**  *parent) const
    {
            MyCustomWidget *widget = qobject_cast<MyCustomWidget*>(object);
    if (widget && (iid == Q_TYPEID(**QDesignerContainerExtension** ))) {
    return new MyContainerExtension(widget, parent);

            } else if
    (widget && (iid == Q_TYPEID(QDesignerTaskMenuExtension))) {
    return new MyTaskMenuExtension(widget, parent);

            } else {
    return 0;
            }
        }

    For a complete example using the QDesignerTaskMenuExtension class, see the
    **Task Menu Extension example** . The example shows how to create a custom
    widget plugin for **Qt Designer** , and how to to use the
    QDesignerTaskMenuExtension class to add custom items to **Qt Designer** 's
    task menu.

    **See also** **QExtensionFactory** , **QExtensionManager** , and **Creating
    Custom Widget Extensions** .
    """

    def __init__(self) -> None:
        ...

    def preferredEditAction(self) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qdesignertaskmenuextension.html#preferredEditActi
        on

        **[virtual] QAction *QDesignerTaskMenuExtension::preferredEditAction()
        const**

        Returns the action that is invoked when selecting a plugin with the
        specified extension and pressing **F2**.

        The action must be one of the actions returned by **taskActions** ().
        """
        ...

    def taskActions(self) -> typing.List[QtGui.QAction]:
        """
        https://doc.qt.io/qt-6/qdesignertaskmenuextension.html#taskActions

        **[pure virtual] QList<QAction *>
        QDesignerTaskMenuExtension::taskActions() const**

        Returns the task menu extension as a list of actions which will be
        included in **Qt Designer** 's task menu when a plugin with the
        specified extension is selected.

        The function must be reimplemented to add actions to the list.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QPointingDevice(QInputDevice):
    """
    https://doc.qt.io/qt-6/qpointingdevice.html

    **Detailed Description**

    Each **QPointerEvent**  contains a QPointingDevice pointer to allow
    accessing device-specific properties like type and capabilities. It is the
    responsibility of the platform or generic plug-ins to register the available
    pointing devices via QWindowSystemInterface before generating any pointer
    events. Applications do not need to instantiate this class, they should just
    access the global instances pointed to by **QPointerEvent::device** ().
    """

    class PointerType(enum.Flag):
        Unknown: QPointingDevice = ...
        Generic: QPointingDevice = ...
        Finger: QPointingDevice = ...
        Pen: QPointingDevice = ...
        Eraser: QPointingDevice = ...
        Cursor: QPointingDevice = ...
        AllPointerTypes: QPointingDevice = ...

    @typing.overload
    def __init__(
        self,
        name: str,
        systemId: int,
        devType: QInputDevice.DeviceType,
        pType: "QPointingDevice.PointerType",
        caps: QInputDevice.Capability,
        maxPoints: int,
        buttonCount: int,
        seatName: str = ...,
        uniqueId: QPointingDeviceUniqueId = ...,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpointingdevice.html#QPointingDevice

        **QPointingDevice::QPointingDevice(QObject * parent = nullptr)**

        Creates a new invalid pointing device instance as a child of **parent**.
        """
        ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qpointingdevice.html#QPointingDevice-1

        **QPointingDevice::QPointingDevice(const QString & name , qint64 id ,
        QInputDevice::DeviceType deviceType , QPointingDevice::PointerType
        pointerType , QInputDevice::Capabilities capabilities , int maxPoints ,
        int buttonCount , const QString & seatName = QString(),
        QPointingDeviceUniqueId uniqueId = QPointingDeviceUniqueId(), QObject *
        parent = nullptr)**

        Creates a new pointing device instance with the given **name** ,
        **deviceType** , **pointerType** , **capabilities** , **maxPoints** ,
        **buttonCount** , **seatName** , **uniqueId** and **parent**.
        """
        ...

    @staticmethod
    def primaryPointingDevice(seatName: str = ...) -> "QPointingDevice":
        """
        https://doc.qt.io/qt-6/qpointingdevice.html#primaryPointingDevice

        **[static] const QPointingDevice
        *QPointingDevice::primaryPointingDevice(const QString & seatName =
        QString())**

        Returns the primary pointing device (the core pointer, traditionally
        assumed to be a mouse) on the given seat **seatName**.

        If multiple pointing devices are registered, this function prefers a
        mouse or touchpad that matches the given **seatName** and that does not
        have another device as its parent. Usually only one master or core
        device does not have a parent device. But if such a device is not found,
        this function creates a new virtual "core pointer" mouse. Thus Qt
        continues to work on platforms that are not yet doing input device
        discovery and registration.
        """
        ...

    def uniqueId(self) -> QPointingDeviceUniqueId:
        """
        https://doc.qt.io/qt-6/qpointingdevice.html#uniqueId

        **QPointingDeviceUniqueId QPointingDevice::uniqueId() const**

        Returns a unique ID (of dubious utility) for the device.

        You probably should rather be concerned with
        QPointerEventPoint::uniqueId().

        **Note:** Getter function for property uniqueId.
        """
        ...

    def buttonCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qpointingdevice.html#buttonCount

        **int QPointingDevice::buttonCount() const**

        Returns the maximum number of on-device buttons that can be detected.

        **Note:** Getter function for property buttonCount.
        """
        ...

    def maximumPoints(self) -> int:
        """
        https://doc.qt.io/qt-6/qpointingdevice.html#maximumPoints

        **int QPointingDevice::maximumPoints() const**

        Returns the maximum number of simultaneous touch points (fingers) that
        can be detected.

        **Note:** Getter function for property maximumPoints.
        """
        ...

    def pointerType(self) -> "QPointingDevice.PointerType":
        """
        https://doc.qt.io/qt-6/qpointingdevice.html#pointerType

        **QPointingDevice::PointerType QPointingDevice::pointerType() const**

        Returns the pointer type.

        **Note:** Getter function for property pointerType.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QValidator(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qvalidator.html

    **Detailed Description**

    The class itself is abstract. Two subclasses, **QIntValidator**  and
    **QDoubleValidator** , provide basic numeric-range checking, and
    **QRegularExpressionValidator**  provides general checking using a custom
    regular expression.

    If the built-in validators aren't sufficient, you can subclass QValidator.
    The class has two virtual functions: **validate** () and **fixup** ().

    **validate** () must be implemented by every subclass. It returns
    **Invalid** , **Intermediate**  or **Acceptable**  depending on whether its
    argument is valid (for the subclass's definition of valid).

    These three states require some explanation. An **Invalid**  string is
    **clearly** invalid. **Intermediate**  is less obvious: the concept of
    validity is difficult to apply when the string is incomplete (still being
    edited). QValidator defines **Intermediate**  as the property of a string
    that is neither clearly invalid nor acceptable as a final result.
    **Acceptable**  means that the string is acceptable as a final result. One
    might say that any string that is a plausible intermediate state during
    entry of an **Acceptable**  string is **Intermediate** .

    Here are some examples:

    * For a line edit that accepts integers from 10 to 1000 inclusive, 42 and
    123 are **Acceptable** , the empty string, 5, or 1234 are **Intermediate** ,
    and "asdf" and 10114 is **Invalid** .
      * For an editable combobox that
    accepts URLs, any well-formed URL is **Acceptable** , "http://example.com/,"
    is **Intermediate**  (it might be a cut and paste action that accidentally
    took in a comma at the end), the empty string is **Intermediate**  (the user
    might select and delete all of the text in preparation for entering a new
    URL) and "http:///./" is **Invalid** .
      * For a spin box that accepts
    lengths, "11cm" and "1in" are **Acceptable** , "11" and the empty string are
    **Intermediate** , and "http://example.com" and "hour" are **Invalid** .

    **fixup** () is provided for validators that can repair some user errors.
    The default implementation does nothing. **QLineEdit** , for example, will
    call **fixup** () if the user presses Enter (or Return) and the content is
    not currently valid. This allows the **fixup** () function the opportunity
    of performing some magic to make an **Invalid**  string **Acceptable** .

    A validator has a locale, set with **setLocale** (). It is typically used to
    parse localized data. For example, **QIntValidator**  and
    **QDoubleValidator**  use it to parse localized representations of integers
    and doubles.

    QValidator is typically used with **QLineEdit** , **QSpinBox**  and
    **QComboBox** .

    **See also** **QIntValidator** , **QDoubleValidator** ,
    **QRegularExpressionValidator** , and **Line Edits Example** .
    """

    class State(enum.Enum):
        Invalid: QValidator = ...
        Intermediate: QValidator = ...
        Acceptable: QValidator = ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qvalidator.html#QValidator

        **QValidator::QValidator(QObject * parent = nullptr)**

        Sets up the validator. The **parent** parameter is passed on to the
        **QObject**  constructor.
        """
        ...

    def locale(self) -> QtCore.QLocale:
        """
        https://doc.qt.io/qt-6/qvalidator.html#locale

        **QLocale QValidator::locale() const**

        Returns the locale for the validator. The locale is by default
        initialized to the same as QLocale().

        **See also** **setLocale** () and **QLocale::QLocale** ().
        """
        ...

    def setLocale(self, locale: QtCore.QLocale) -> None:
        """
        https://doc.qt.io/qt-6/qvalidator.html#setLocale

        **void QValidator::setLocale(const QLocale & locale )**

        Sets the **locale** that will be used for the validator. Unless
        setLocale has been called, the validator will use the default locale set
        with **QLocale::setDefault** (). If a default locale has not been set,
        it is the operating system's locale.

        **See also** **locale** () and **QLocale::setDefault** ().
        """
        ...

    def fixup(self, a0: str) -> str:
        """
        https://doc.qt.io/qt-6/qvalidator.html#fixup

        **[virtual] void QValidator::fixup(QString & input ) const**

        This function attempts to change **input** to be valid according to this
        validator's rules. It need not result in a valid string: callers of this
        function must re-test afterwards; the default does nothing.

        Reimplementations of this function can change **input** even if they do
        not produce a valid string. For example, an ISBN validator might want to
        delete every character except digits and "-", even if the result is
        still not a valid ISBN; a surname validator might want to remove
        whitespace from the start and end of the string, even if the resulting
        string is not in the list of accepted surnames.
        """
        ...

    def validate(self, a0: str, a1: int) -> typing.Tuple["QValidator.State", str, int]:
        """
        https://doc.qt.io/qt-6/qvalidator.html#validate

        **[pure virtual] QValidator::State QValidator::validate(QString & input
        , int & pos ) const**

        This virtual function returns **Invalid**  if **input** is invalid
        according to this validator's rules, **Intermediate**  if it is likely
        that a little more editing will make the input acceptable (e.g. the user
        types "4" into a widget which accepts integers between 10 and 99), and
        **Acceptable**  if the input is valid.

        The function can change both **input** and **pos** (the cursor position)
        if required.
        """
        ...

    @property
    def changed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qvalidator.html#changed

        **[signal] void QValidator::changed()**

        This signal is emitted when any property that may affect the validity of
        a string has changed.
        """
        ...
